@@ -153,6 +153,13 @@ class ScriptJob(GenericJob):
                 "path should be a string, but ", path, " is a ", type(path), " instead."
             )
 
+    def validate_ready_to_run(self):
+        if self.script_path is None:
+            raise TypeError(
+                'ScriptJob.script_path expects a path but got None. Please provide a path before '
+                + 'running.'
+            )
+
     def set_input_to_read_only(self):
         """
         This function enforces read-only mode for the input classes, but it has to be implement in the individual
